@@ -24,9 +24,11 @@ Create Dragonfly Buildings from solid geometry (closed Rhino polysurfaces).
             of these text strings will divide up floors accordingly.  For example,
             the list ["1@5", "2@4", "@3"]  will make a ground floor of 5 units,
             two floors above that at 4 units and all remaining floors at 3 units.
-        _name_: A base name to be used for the Buildings. This will be combined
-            with the index of each input _geo to yield a unique name for each
-            output Building.
+         _name_: Text to set the base name for the Building, which will also be
+            incorporated into unique Building identifier. This will be combined
+            with the index of each input _bldg_geo to yield a unique name
+            for each output Building. If the name is not provided, a random one
+            will be assigned.
         _program_: Text for the program of the Buildings (to be looked up in the
             ProgramType library) such as that output from the "HB List Programs"
             component. This can also be a custom ProgramType object. If no program
@@ -49,7 +51,7 @@ Create Dragonfly Buildings from solid geometry (closed Rhino polysurfaces).
 
 ghenv.Component.Name = "DF Building from Solid"
 ghenv.Component.NickName = 'BuildingSolid'
-ghenv.Component.Message = '0.1.1'
+ghenv.Component.Message = '0.1.3'
 ghenv.Component.Category = "Dragonfly"
 ghenv.Component.SubCategory = '0 :: Create'
 ghenv.Component.AdditionalHelpFromDocStrings = "2"
@@ -61,6 +63,11 @@ try:
 except KeyError:  # first time that the component is running
     scriptcontext.sticky["bldg_count"] = 1
 
+try:  # import the core honeybee dependencies
+    from honeybee.typing import clean_and_id_string
+except ImportError as e:
+    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
+
 try:  # import the core dragonfly dependencies
     from dragonfly.building import Building
     from dragonfly.subdivide import interpret_floor_height_subdivide
@@ -71,14 +78,15 @@ try:  # import the core ladybug_rhino dependencies
     from ladybug_rhino.config import tolerance
     from ladybug_rhino.intersect import split_solid_to_floors, geo_min_max_height
     from ladybug_rhino.togeometry import to_face3d
+    from ladybug_rhino.fromgeometry import from_face3d
     from ladybug_rhino.grasshopper import all_required_inputs
 except ImportError as e:
     raise ImportError('\nFailed to import ladybug_rhino:\n\t{}'.format(e))
 
 try:  # import the dragonfly-energy extension
     import dragonfly_energy
-    from honeybee_energy.lib.programtypes import program_type_by_name, office_program
-    from honeybee_energy.lib.constructionsets import construction_set_by_name
+    from honeybee_energy.lib.programtypes import program_type_by_identifier, office_program
+    from honeybee_energy.lib.constructionsets import construction_set_by_identifier
 except ImportError as e:
     if _program_ is not None:
         raise ValueError('_program_ has been specified but dragonfly-energy '
@@ -90,53 +98,64 @@ except ImportError as e:
         raise ValueError('conditioned_ has been specified but dragonfly-energy '
                          'has failed to import.\n{}'.format(e))
 
+import uuid
+
 
 if all_required_inputs(ghenv.Component) and _run:
     buildings = []  # list of buildings that will be returned
-    
+
     for i, geo in enumerate(_bldg_geo):
         # get the name for the Building
         if _name_ is None:  # make a default Building name
-            name = "Building_{}".format(scriptcontext.sticky["bldg_count"])
+            name = "Building_{}_{}".format(scriptcontext.sticky["bldg_count"],
+                                           str(uuid.uuid4())[:8])
             scriptcontext.sticky["bldg_count"] += 1
         else:
-            name = '{}_{}'.format(_name_, i + 1)
-        
+            display_name = '{}_{}'.format(_name_, i + 1)
+            name = clean_and_id_string(display_name)
+
         # interpret the input _floor_to_floor information
         min, max = geo_min_max_height(geo)
         floor_heights, interpreted_f2f = interpret_floor_height_subdivide(
             _floor_to_floor, max, min)
-        
+
         # get the floor geometries of the building
         floor_breps = split_solid_to_floors(geo, floor_heights)
-        floor_faces = [to_face3d(flr) for flr in floor_breps]
-        
+        floor_faces = []
+        for flr in floor_breps:
+            story_faces = []
+            for rm_face in flr:
+                story_faces.extend(to_face3d(rm_face))
+            floor_faces.append(story_faces)
+
         # create the Building
-        building = Building.from_all_story_geometry(name, floor_faces,
-                                                    interpreted_f2f, tolerance)
-        
+        building = Building.from_all_story_geometry(
+            name, floor_faces, interpreted_f2f, tolerance)
+        if _name_ is not None:
+            building.display_name = display_name
+
         # assign the program
         if _program_ is not None:
             if isinstance(_program_, str):
-                _program_ = program_type_by_name(_program_)
+                _program_ = program_type_by_identifier(_program_)
             building.properties.energy.set_all_room_2d_program_type(_program_)
         else:  # generic office program by default
             try:
                 building.properties.energy.set_all_room_2d_program_type(office_program)
             except (NameError, AttributeError):
                 pass  # honeybee-energy is not installed
-        
+
         # assign the construction set
         if _constr_set_ is not None:
             if isinstance(_constr_set_, str):
-                _constr_set_ = construction_set_by_name(_constr_set_)
+                _constr_set_ = construction_set_by_identifier(_constr_set_)
             building.properties.energy.construction_set = _constr_set_
-        
+
         # assign an ideal air system
         if conditioned_ or conditioned_ is None:  # conditioned by default
             try:
                 building.properties.energy.add_default_ideal_air()
             except (NameError, AttributeError):
                 pass  # honeybee-energy is not installed
-        
+
         buildings.append(building)
